==> onefetch-2.10.1.crate: onefetch-2.10.1/docs/README.ja.md <==
<h3 align="center"><img src="../assets/onefetch.svg" height="130px"></h3>

<h5 align="center">‎Rustで書かれたコマンドラインインターフェースのGit情報ツール‎</h5>

<p align="center">
	<a href="https://crates.io/crates/onefetch"><img src="https://img.shields.io/crates/v/onefetch.svg" alt="cargo"></a>
	<a href="https://github.com/o2sh/onefetch/actions"><img src="https://github.com/o2sh/onefetch/workflows/CI/badge.svg" alt="Build Status"></a>
	<a href="https://github.com/o2sh/onefetch/issues?q=is%3Aissue+is%3Aopen+label%3A%22help+wanted%22"><img src="https://img.shields.io/github/issues/o2sh/onefetch/help%20wanted?color=green" alt="help wanted"></a>
	<a href="./LICENSE.md"><img src="https://img.shields.io/badge/license-MIT-blue.svg"></a>
</p>

<img src="../assets/react.png" align="right" height="240px">

Onefetchは`Rust`で書かれたコマンドラインインターフェースのGit情報ツールで、ローカルにあるGitリポジトリのプロジェクト情報やコードの統計をターミナルへ直接表示します。このツールは常にオフラインで動作し、ネットワークへのアクセスは必要ありません。

‎デフォルトの設定ではリポジトリ内の情報は主要な言語のロゴと一緒に表示されますが、代わりに画像（ターミナルでサポートされている場合）やテキスト、または何も表示しないように設定できます。

テキストからオープンソースライセンスを自動的に検出し、ソースコードの配布ページや保留中の変更、依存関係の数（パッケージマネージャーによる）、トップコントリビューター（コミット数による）、ディスク上のサイズ、作成日、LOC（コードの行数）などの有益な情報をユーザーに提供します。

<img src="../assets/kubernetes.png" align="right" height="240px">

Onefetchはコマンドラインフラグを使用してASCII/テキストフォーマットのカスタマイズや情報行の無効化、ファイルやディレクトリの除外、複数のフォーマット（JSON、YAML）での出力など設定できます。

‎現在、Onefetchは50種類以上のプログラミング言語をサポートしています。選択した言語がサポートされていない場合はIssueを追加してください。

貢献は大歓迎です。詳しくは [CONTRIBUTING](https://github.com/o2sh/onefetch/blob/main/CONTRIBUTING.md) をご覧ください。

### 詳細: \[[Wiki](https://github.com/o2sh/onefetch/wiki)\] \[[Installation](https://github.com/o2sh/onefetch/wiki/Installation)\] \[[Getting Started](https://github.com/o2sh/onefetch/wiki/getting-started)\]

==> onefetch-2.10.2.crate: onefetch-2.10.2/docs/README.ja.md <==
<h3 align="center"><img src="../assets/onefetch.svg" height="130px"></h3>

<h5 align="center">‎Rustで書かれたコマンドラインインターフェースのGit情報ツール‎</h5>

<p align="center">
	<a href="https://crates.io/crates/onefetch"><img src="https://img.shields.io/crates/v/onefetch.svg" alt="cargo"></a>
	<a href="https://github.com/o2sh/onefetch/actions"><img src="https://github.com/o2sh/onefetch/workflows/CI/badge.svg" alt="Build Status"></a>
	<a href="https://github.com/o2sh/onefetch/issues?q=is%3Aissue+is%3Aopen+label%3A%22help+wanted%22"><img src="https://img.shields.io/github/issues/o2sh/onefetch/help%20wanted?color=green" alt="help wanted"></a>
	<a href="./LICENSE.md"><img src="https://img.shields.io/badge/license-MIT-blue.svg"></a>
</p>

<img src="../assets/screenshot-1.png" align="right" height="240px">

Onefetchは`Rust`で書かれたコマンドラインインターフェースのGit情報ツールで、ローカルにあるGitリポジトリのプロジェクト情報やコードの統計をターミナルへ直接表示します。このツールは常にオフラインで動作し、ネットワークへのアクセスは必要ありません。

‎デフォルトの設定ではリポジトリ内の情報は主要な言語のロゴと一緒に表示されますが、代わりに画像（ターミナルでサポートされている場合）やテキスト、または何も表示しないように設定できます。

テキストからオープンソースライセンスを自動的に検出し、ソースコードの配布ページや保留中の変更、依存関係の数（パッケージマネージャーによる）、トップコントリビューター（コミット数による）、ディスク上のサイズ、作成日、LOC（コードの行数）などの有益な情報をユーザーに提供します。

<img src="../assets/screenshot-2.png" align="right" height="240px">

Onefetchはコマンドラインフラグを使用してASCII/テキストフォーマットのカスタマイズや情報行の無効化、ファイルやディレクトリの除外、複数のフォーマット（JSON、YAML）での出力など設定できます。

‎現在、Onefetchは50種類以上のプログラミング言語をサポートしています。選択した言語がサポートされていない場合はIssueを追加してください。

貢献は大歓迎です。詳しくは [CONTRIBUTING](https://github.com/o2sh/onefetch/blob/main/CONTRIBUTING.md) をご覧ください。

### 詳細: \[[Wiki](https://github.com/o2sh/onefetch/wiki)\] \[[Installation](https://github.com/o2sh/onefetch/wiki/Installation)\] \[[Getting Started](https://github.com/o2sh/onefetch/wiki/getting-started)\]
